summaryrefslogtreecommitdiff
path: root/lib/net/imap.rb
diff options
context:
space:
mode:
Diffstat (limited to 'lib/net/imap.rb')
-rw-r--r--lib/net/imap.rb5
1 files changed, 3 insertions, 2 deletions
diff --git a/lib/net/imap.rb b/lib/net/imap.rb
index 2398a5d10c..394f0d9890 100644
--- a/lib/net/imap.rb
+++ b/lib/net/imap.rb
@@ -892,7 +892,7 @@ module Net
# OpenSSL [OSSL] and the Ruby OpenSSL [RSSL] extensions need to
# be installed.
# if options[:ssl] is a hash, it's passed to
# OpenSSL::SSL::SSLContext.build as parameters.
#
# The most common errors are:
#
@@ -1263,7 +1263,8 @@ module Net
rescue NoMethodError
params = {}
end
- context = SSLContext.build(params)
+ context = SSLContext.new
+ context.set_params(params)
if defined?(VerifyCallbackProc)
context.verify_callback = VerifyCallbackProc
end
@@ -892,7 +892,7 @@ module Net
# be installed.
# if options[:ssl] is a hash, it's passed to
- # OpenSSL::SSL::SSLContext.build as parameters.
+ # OpenSSL::SSL::SSLContext#set_params as parameters.
#
# The most common errors are: